==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/eventhub/kotlin/inputs/NWRuleSetIpRulesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.eventhub.kotlin.inputs

import com.pulumi.azurenative.eventhub.inputs.NWRuleSetIpRulesArgs.builder
import com.pulumi.azurenative.eventhub.kotlin.enums.NetworkRuleIPAction
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The response from the List namespace operation.
 * @property action The IP Filter Action
 * @property ipMask IP Mask
 */
public data class NWRuleSetIpRulesArgs(
    public val action: Output<Either<String, NetworkRuleIPAction>>? = null,
    public val ipMask: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.eventhub.inputs.NWRuleSetIpRulesArgs> {
    override fun toJava(): com.pulumi.azurenative.eventhub.inputs.NWRuleSetIpRulesArgs =
        com.pulumi.azurenative.eventhub.inputs.NWRuleSetIpRulesArgs.builder()
            .action(
                action?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .ipMask(ipMask?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [NWRuleSetIpRulesArgs].
 */
@PulumiTagMarker
public class NWRuleSetIpRulesArgsBuilder internal constructor() {
    private var action: Output<Either<String, NetworkRuleIPAction>>? = null

    private var ipMask: Output<String>? = null

    /**
     * @param value The IP Filter Action
     */
    @JvmName("higpdhvfvhbywkwp")
    public suspend fun action(`value`: Output<Either<String, NetworkRuleIPAction>>) {
        this.action = value
    }

    /**
     * @param value IP Mask
     */
    @JvmName("icxjrfcngfyerfbh")
    public suspend fun ipMask(`value`: Output<String>) {
        this.ipMask = value
    }

    /**
     * @param value The IP Filter Action
     */
    @JvmName("qwfkrcfxiuueovab")
    public suspend fun action(`value`: Either<String, NetworkRuleIPAction>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value The IP Filter Action
     */
    @JvmName("gcpltsvfidtprsth")
    public fun action(`value`: String) {
        val toBeMapped = Either.ofLeft<String, NetworkRuleIPAction>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value The IP Filter Action
     */
    @JvmName("oadptdfqhxpxfyex")
    public fun action(`value`: NetworkRuleIPAction) {
        val toBeMapped = Either.ofRight<String, NetworkRuleIPAction>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value IP Mask
     */
    @JvmName("ufhpscrxfhslnbjk")
    public suspend fun ipMask(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ipMask = mapped
    }

    internal fun build(): NWRuleSetIpRulesArgs = NWRuleSetIpRulesArgs(
        action = action,
        ipMask = ipMask,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/eventhub/kotlin/inputs/NWRuleSetIpRulesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.eventhub.kotlin.inputs

import com.pulumi.azurenative.eventhub.inputs.NWRuleSetIpRulesArgs.builder
import com.pulumi.azurenative.eventhub.kotlin.enums.NetworkRuleIPAction
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The response from the List namespace operation.
 * @property action The IP Filter Action
 * @property ipMask IP Mask
 */
public data class NWRuleSetIpRulesArgs(
    public val action: Output<Either<String, NetworkRuleIPAction>>? = null,
    public val ipMask: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.eventhub.inputs.NWRuleSetIpRulesArgs> {
    override fun toJava(): com.pulumi.azurenative.eventhub.inputs.NWRuleSetIpRulesArgs =
        com.pulumi.azurenative.eventhub.inputs.NWRuleSetIpRulesArgs.builder()
            .action(
                action?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .ipMask(ipMask?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [NWRuleSetIpRulesArgs].
 */
@PulumiTagMarker
public class NWRuleSetIpRulesArgsBuilder internal constructor() {
    private var action: Output<Either<String, NetworkRuleIPAction>>? = null

    private var ipMask: Output<String>? = null

    /**
     * @param value The IP Filter Action
     */
    @JvmName("fhsgmbnvbjigtdye")
    public suspend fun action(`value`: Output<Either<String, NetworkRuleIPAction>>) {
        this.action = value
    }

    /**
     * @param value IP Mask
     */
    @JvmName("nxrlvwybcpsxbqkr")
    public suspend fun ipMask(`value`: Output<String>) {
        this.ipMask = value
    }

    /**
     * @param value The IP Filter Action
     */
    @JvmName("owxwooihojftyokv")
    public suspend fun action(`value`: Either<String, NetworkRuleIPAction>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value The IP Filter Action
     */
    @JvmName("hdaqyhskcsoxcott")
    public fun action(`value`: String) {
        val toBeMapped = Either.ofLeft<String, NetworkRuleIPAction>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value The IP Filter Action
     */
    @JvmName("bahartpldgnugwuu")
    public fun action(`value`: NetworkRuleIPAction) {
        val toBeMapped = Either.ofRight<String, NetworkRuleIPAction>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value IP Mask
     */
    @JvmName("dycvoteecanywxfc")
    public suspend fun ipMask(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ipMask = mapped
    }

    internal fun build(): NWRuleSetIpRulesArgs = NWRuleSetIpRulesArgs(
        action = action,
        ipMask = ipMask,
    )
}
